@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "emacsc" "1.6.20250711"
+(define-package "emacsc" "20250710.1637"
   "Helper for emacsc(1)."
   ()
   :url "https://github.com/knu/emacsc"
